@@ -30,6 +30,8 @@
 static char Help_string[] = "";
 static int Transformations = 0;
 
+#define BUF_MAX 1000
+
 /*************
  *
  *   read_heading()
@@ -39,17 +41,17 @@ static int Transformations = 0;
 static
 String_buf read_heading(FILE *fp)
 {
-  char line[1000], *s;  /* the first 999 chars of the line */
+  char line[BUF_MAX], *s;  /* the first BUF_MAX-1 chars of the line */
   String_buf sb = get_string_buf();
   int i = 0;
 
-  s = fgets(line, 1000, fp);
+  s = fgets(line, BUF_MAX, fp);
   while (s && !substring("= end of head =", s)) {
     if (i != 0) {
       sb_append(sb, s);
     }
     i++;
-    s = fgets(line, 1000, fp);
+    s = fgets(line, BUF_MAX, fp);
   }
 
   if (!s)
@@ -67,11 +69,11 @@ String_buf read_heading(FILE *fp)
 static
 void read_program_input(FILE *fp)
 {
-  char line[1000], *s;       /* the first 999 chars of the line */
+  char line[BUF_MAX], *s;       /* the first BUF_MAX-1 chars of the line */
   BOOL in_list = FALSE;      /* parsing list of clauses, formulas, or terms? */
   Plist lang_commands = NULL;  /* in case of multiple identical commands */
 
-  s = fgets(line, 1000, fp);
+  s = fgets(line, BUF_MAX, fp);
   while (s && !substring("= end of input =", s)) {
     if (in_list)
       in_list = !initial_substring("end_of_list.", line);
@@ -95,7 +97,7 @@ void read_program_input(FILE *fp)
       set_variable_style(PROLOG_STYLE);
     }
     
-    s = fgets(line, 1000, fp);
+    s = fgets(line, BUF_MAX, fp);
   }
   
   if (!s)
@@ -114,11 +116,11 @@ void read_program_input(FILE *fp)
 static
 BOOL read_to_line(FILE *fp, char *str)
 {
-  char line[1000], *s;  /* the first 999 chars of the line */
+  char line[BUF_MAX], *s;  /* the first BUF_MAX-1 chars of the line */
   
-  s = fgets(line, 1000, fp);
+  s = fgets(line, BUF_MAX, fp);
   while (s && !substring(str, line))
-    s = fgets(line, 1000, fp);
+    s = fgets(line, BUF_MAX, fp);
 
   return s != NULL;
 }  /* read_to_line */
@@ -505,6 +507,11 @@ Plist forward_proof(Plist proof)
     else if (p1 && n1->justification->type == PARA_JUST &&
 	     n1->justification->next == NULL) {
       /* CASE 3: para into negative clause, then unit conflict. */
+      Ilist p2_pos;
+      Ilist n2_pos;
+      Term target;
+      Topform new1, empty;
+      Ilist from_pos;
       if (e->justification->u.lst->next->i == -1 ||
 	  e->justification->u.lst->next->next->next->i == -1) {
 	/* The unit conflict involved an implicit flip.  We'll handle that by
@@ -516,9 +523,9 @@ Plist forward_proof(Plist proof)
 	p1 = flipped_pos;
       }
 
-      Ilist p2_pos = n1->justification->u.para->from_pos;
-      Ilist n2_pos = n1->justification->u.para->into_pos;
-      Term target = term_at_position(p1->literals, n2_pos);
+      p2_pos = n1->justification->u.para->from_pos;
+      n2_pos = n1->justification->u.para->into_pos;
+      target = term_at_position(p1->literals, n2_pos);
       if (!target) {
 	/* Into_term does not exist, so we have to instantiate p1. */
 	Term pair = instance_from_position(p1, n1, n2_pos);
@@ -532,8 +539,7 @@ Plist forward_proof(Plist proof)
 	proof = plist_append(proof, p1i);
 	p1 = p1i;
       }
-      Topform new1, empty;
-      Ilist from_pos = copy_ilist(p2_pos);
+      from_pos = copy_ilist(p2_pos);
       from_pos->next->i = (p2_pos->next->i == 1 ? 2 : 1);
       new1 = para_pos2(p2, from_pos, p1, n2_pos);
       zap_ilist(from_pos);
@@ -691,18 +697,26 @@ int main(int argc, char **argv)
     /* ok, we have a proof */
     String_buf comment = get_string_buf();
 
-    char s[1000];
+    char s[BUF_MAX];
     Plist proof = NULL;
     number_of_proofs++;
 
     rc = fscanf(fin, "%s", s);         /* "%" or clause id */
     while (str_ident(s, "%")) {
-      fgets(s, 1000, fin);
+      fgets(s, BUF_MAX, fin);
       /* in case prooftrans is run multiple times */
       if (!substring("Comments from original proof", s)) {
 	sb_append(comment, "%");
 	sb_append(comment, s);
       }
+      /* in case there are any long comment lines (answers) */
+      if (s[strlen(s)] != '\n') {
+	char c;
+	do {
+	  c = fgetc(fin);
+	  sb_append_char(comment, c);
+	} while (c != '\n');
+      }
       rc = fscanf(fin, "%s", s);       /* "%" or clause id */
     }
 
@@ -734,13 +748,17 @@ int main(int argc, char **argv)
     String_buf comment = c->v;
 
     Plist xproof = expand_proof(proof, &jmap);
+    Plist xnproof;
+    /* delete_clauses(xproof); */
+
+    Plist xnfproof;
     zap_i3list(jmap);
     /* delete_clauses(proof); */
 
-    Plist xnproof = copy_and_renumber_proof(xproof, 1);
+    xnproof = copy_and_renumber_proof(xproof, 1);
     /* delete_clauses(xproof); */
 
-    Plist xnfproof = forward_proof(xnproof);
+    xnfproof = forward_proof(xnproof);
     /* delete_clauses(xnproof); */
 
     print_proof(stdout, xnfproof, comment, CL_FORM_STD, NULL, n);
