@@ -33,7 +33,7 @@ int main(int argc, char **argv)
   Plist rules = NULL;
 
   init_standard_ladr();
-  init_weight(NULL, 1, 1, 0, 0, 1, 1, 0, 0, 0);
+  init_weight(NULL, 1, 1, 0, 0, 1, 1, 0, 0, 0, 0);
   i = register_attribute("label",  STRING_ATTRIBUTE);  /* ignore these */
   i = register_attribute("answer", TERM_ATTRIBUTE);  /* ignore these */
 
@@ -41,7 +41,7 @@ int main(int argc, char **argv)
   if (rule_fp == NULL)
     fatal_error("test_clause_eval, rule file cannot be opened for reading");
 
-  t = read_term(rule_fp, stderr);  /* get first interpretation */
+  t = read_term(rule_fp, stderr);  /* get first rule */
 
   while (t != NULL) {
     compiled_rule = compile_clause_eval_rule(t);
