@@ -39,6 +39,9 @@
 
 void flatten(Term t, Term *a, int *ip);
 
+void ac_canonical2(Term t, int bit,
+		   Ordertype (*term_compare_proc) (Term, Term));
+
 void ac_canonical(Term t, int bit);
 
 int check_ac_canonical(Term t);
