@@ -650,13 +650,13 @@ Term build_attr_term(Attribute a)
   switch (type) {
   case INT_ATTRIBUTE:
     {
-      char s[50];
+      char s[25];
       if (a->u.i < 0) {
 	ARG(t,0) = get_rigid_term("-", 1);
-	ARG(ARG(t,0),0) = get_rigid_term(itoa(-(a->u.i), s), 0);
+	ARG(ARG(t,0),0) = get_rigid_term(int_to_str(-(a->u.i), s, 25), 0);
       }
       else {
-	ARG(t,0) = get_rigid_term(itoa(a->u.i, s), 0);
+	ARG(t,0) = get_rigid_term(int_to_str(a->u.i, s, 25), 0);
       }
       break;
     }
