@@ -61,13 +61,7 @@ BOOL is_definition(Formula f)
 
     if (ok) {
       /* check that the defined symbol does not occur in the right side */
-      I2list p2 = NULL;
-      Ilist p;
-      p2 = relation_symbols_in_formula(g->kids[1], p2);
-      p = multiset_to_set(p2);
-      ok = !ilist_member(p, SYMNUM(g->kids[0]->atom));
-      zap_i2list(p2);
-      zap_ilist(p);
+      ok = !relation_symbol_in_formula(SYMNUM(g->kids[0]->atom), g->kids[1]);
     }
 
     return ok;
