@@ -100,7 +100,7 @@ void init_dollar_eval(Clist rules)
   Op_codes[str_to_sn("|", 2)]        = OR_OP;
   Op_codes[str_to_sn("if", 3)]       = IF_OP;
 
-  Rules = calloc(Symbols_size, sizeof(int));
+  Rules = calloc(Symbols_size, sizeof(void *));
 
   for (p = rules->last; p; p = p->prev) {  /* backward */
     Topform c = p->c;
@@ -421,7 +421,7 @@ Term rewrite(Term t, int flag, I3list *steps)
   if (term_flag(t, flag) || VARIABLE(t))
     return t;
   else {
-    int op_code = Op_codes[SYMNUM(t)];
+    int op_code = (SYMNUM(t) < Symbols_size ? Op_codes[SYMNUM(t)] : -1);
     int i;
 
     switch (op_code) {
