@@ -20,7 +20,7 @@
 #ifndef TP_DOLLAR_H
 #define TP_DOLLAR_H
 
-#include "unify.h"
+#include "clist.h"
 
 /* INTRODUCTION
 */
@@ -31,14 +31,12 @@
 
 /* Public function prototypes from dollar.c */
 
-void init_dollar_eval(void);
+void init_dollar_eval(Clist rules);
+
+BOOL evaluable_predicate(int symnum);
 
 Term dollar_eval(Term t);
 
-Term rewrite_top(Term t, Plist rules, int flag);
-
-Term rewrite(Term t, Plist rules, int flag);
-
-Term programmed_rewrite(Term t, Plist rules);
+void rewrite_with_eval(Topform c);
 
 #endif  /* conditional compilation of whole file */
