@@ -155,8 +155,11 @@ Plist discrim_flat_retrieve_leaf(Flatterm fin, Discrim root,
       status = BACKTRACK;
     else {
       int symnum = SYMNUM(f);
-      while (d && d->symbol < symnum)
+      Discrim dd = NULL;
+      while (d && d->symbol < symnum) {
+	dd = d;
 	d = d->next;
+      }
       if (!d || d->symbol != symnum)
 	status = BACKTRACK;
     }
@@ -257,6 +260,7 @@ void discrim_flat_cancel(Discrim_pos pos)
       pos->subst->terms[f->varnum_bound_to] = NULL;
       f->varnum_bound_to = -1;
     }
+    f->alternative = NULL;
     f = f->prev;
   }
   free_discrim_pos(pos);
