@@ -558,6 +558,34 @@ Plist plist_remove(Plist p, void *v)
   }
 }  /* plist_remove */
 
+/*************
+ *
+ *   plist_remove_string()
+ *
+ *************/
+
+/* DOCUMENTATION
+Remove the first occurrence of a pointer from a Plist.
+*/
+
+/* PUBLIC */
+Plist plist_remove_string(Plist p, char *s)
+{
+  if (p == NULL)
+    fatal_error("plist_remove_string: pointer not found");
+
+  if (str_ident(p->v, s)) {
+    Plist x = p;
+    p = p->next;
+    free_plist(x);
+    return p;
+  }
+  else {
+    p->next = plist_remove_string(p->next, s);
+    return p;
+  }
+}  /* plist_remove_string */
+
 /*************
  *
  *   sort_plist()
@@ -1514,6 +1542,27 @@ int i2list_count(I2list p)
 /*****************************************************************************/
 /*****************************************************************************/
 
+/*************
+ *
+ *   i3list_member()
+ *
+ *************/
+
+/* DOCUMENTATION
+This function checks if a triple of integers is a member of a I3list.
+*/
+
+/* PUBLIC */
+BOOL i3list_member(I3list lst, int i, int j, int k)
+{
+  if (lst == NULL)
+    return FALSE;
+  else if (lst->i == i && lst->j == j && lst->k == k)
+    return TRUE;
+  else
+    return i3list_member(lst->next, i, j, k);
+}  /* i3list_member */
+
 /*************
  *
  *   i3list_append()
