@@ -726,6 +726,26 @@ Just merge_just(int n)
   return j;
 }  /* merge_just */
 
+/*************
+ *
+ *   eval_just()
+ *
+ *************/
+
+/* DOCUMENTATION
+This routine builds and returns a justification for an eval rewrite.
+The argument is the number of rewrites.
+*/
+
+/* PUBLIC */
+Just eval_just(int n)
+{
+  Just j = get_just();
+  j->type = EVAL_JUST;
+  j->u.id = n;
+  return j;
+}  /* eval_just */
+
 /*************
  *
  *   append_just()
@@ -780,6 +800,7 @@ Just copy_justification(Just j)
     case FLIP_JUST:
     case XX_JUST:
     case MERGE_JUST:
+    case EVAL_JUST:
       j2->u.id = j->u.id;
       break;
     case EXPAND_DEF_JUST:
@@ -868,6 +889,7 @@ char *jstring(Just j)
   case FLIP_JUST:          return "flip";
   case XX_JUST:            return "xx";
   case MERGE_JUST:         return "merge";
+  case EVAL_JUST:          return "eval";
   case DEMOD_JUST:         return "rewrite";
   case UNIT_DEL_JUST:      return "unit_del";
   case UNKNOWN_JUST:       return "unknown";
@@ -930,6 +952,8 @@ int jstring_to_jtype(char *s)
     return XX_JUST;
   else if (str_ident(s, "merge"))
     return MERGE_JUST;
+  else if (str_ident(s, "eval"))
+    return EVAL_JUST;
   else if (str_ident(s, "rewrite"))
     return DEMOD_JUST;
   else if (str_ident(s, "unit_del"))
@@ -1156,11 +1180,13 @@ void sb_write_just(String_buf sb, Just just, I3list map)
       sb_append(sb, "([");
       for (p = g->u.demod; p; p = p->next) {
 	sb_append_int(sb, p->i);
-	sb_append(sb, "(");
-	sb_append_int(sb, p->j);
-	if (p->k == 2)
-	  sb_append(sb, ",R");
-	sb_append(sb, ")");
+	if (p->j > 0) {
+	  sb_append(sb, "(");
+	  sb_append_int(sb, p->j);
+	  if (p->k == 2)
+	    sb_append(sb, ",R");
+	  sb_append(sb, ")");
+	}
 
 	sb_append(sb, p->next ? "," : "");
       }
@@ -1234,6 +1260,13 @@ void sb_write_just(String_buf sb, Just just, I3list map)
       sb_append_char(sb, itoc(id));
       sb_append(sb, ")");
     }
+    else if (rule == EVAL_JUST) {
+      int id = g->u.id;
+      sb_append(sb, jstring(g));
+      sb_append(sb, "(");
+      sb_append_int(sb, id);
+      sb_append(sb, ")");
+    }
     else if (rule == PARA_JUST || rule == PARA_FX_JUST ||
 	     rule == PARA_IX_JUST || rule == PARA_FX_IX_JUST) {
       Parajust p = g->u.para;
@@ -1415,6 +1448,7 @@ void zap_just(Just just)
     case FLIP_JUST:
     case XX_JUST:
     case MERGE_JUST:
+    case EVAL_JUST:
       break;  /* nothing to do */
     case EXPAND_DEF_JUST:
     case BINARY_RES_JUST:
@@ -1527,6 +1561,7 @@ Ilist get_parents(Just just, BOOL all)
     else if (rule == FLIP_JUST ||
 	     rule == XX_JUST ||
 	     rule == MERGE_JUST ||
+	     rule == EVAL_JUST ||
 	     rule == GOAL_JUST ||
 	     rule == INPUT_JUST)
       ;  /* do nothing */
@@ -1722,6 +1757,7 @@ void map_just(Just just, I2list map)
     else if (rule == FLIP_JUST ||
 	     rule == XX_JUST ||
 	     rule == MERGE_JUST ||
+	     rule == EVAL_JUST ||
 	     rule == GOAL_JUST ||
 	     rule == INPUT_JUST)
       ;  /* do nothing */
@@ -1912,6 +1948,7 @@ Just term_to_just(Term lst)
 
     case FLIP_JUST:   /* secondary */
     case XX_JUST:     /* secondary */
+    case EVAL_JUST:   /* secondary */
     case MERGE_JUST:  /* secondary */
       {
 	j->u.id = lit_string_to_int(sn_to_str(SYMNUM(ARG(t,0))));
@@ -1945,6 +1982,10 @@ Just term_to_just(Term lst)
 	      term_to_int(ARG(a,0),&j)) {
 	    p = i3list_append(p, i, j, 1);
 	  }
+	  else if (ARITY(a) == 0 &&
+		   str_to_int(s,&i)) {
+	    p = i3list_append(p, i, 0, 1);
+	  }
 	  else
 	    fatal_error("term_to_just: bad justification term (demod 2)");
 	  lst = ARG(lst,1);
@@ -2221,6 +2262,7 @@ void sb_tagged_write_just(String_buf sb, Just just, I3list map)
     }
     else if (rule == FLIP_JUST ||
 	     rule == XX_JUST ||
+	     rule == EVAL_JUST ||
 	     rule == MERGE_JUST) {
       /* int id = g->u.id; */
 
