@@ -1162,4 +1162,23 @@ Term term_at_position(Literals lits, Ilist pos)
   }
 }  /* term_at_position */
 
+/*************
+ *
+ *   pos_predicates()
+ *
+ *************/
+
+/* DOCUMENTATION
+*/
+
+/* PUBLIC */
+Ilist pos_predicates(Ilist p, Literals lits)
+{
+  Literals l;
+  for (l = lits; l; l = l->next) {
+    if (l->sign && ! ilist_member(p, SYMNUM(l->atom)))
+      p = ilist_prepend(p, SYMNUM(l->atom));
+  }
+  return p;
+}  /* pos_predicates */
 
