@@ -17,6 +17,7 @@
 */
 
 #include "resolve.h"
+#include "dollar.h"
 
 /* Private definitions and types */
 
@@ -25,9 +26,11 @@ static BOOL  Check_instances    = FALSE;
 
 static int   Ur_nucleus_limit   = INT_MAX;  /* limit num of clashable lits */
 static BOOL  Initial_nuclei     = FALSE;    /* nuclei must be input clauses  */
+static BOOL  Production_mode    = FALSE;
 
 static int   Res_instance_prunes = 0;  /* counter */
 
+
 /*************
  *
  *   resolution_options()
@@ -42,13 +45,16 @@ static int   Res_instance_prunes = 0;  /* counter */
 void resolution_options(BOOL ordered,
 			BOOL check_instances,
 			BOOL initial_nuclei,
-			int ur_nucleus_limit)
+			int ur_nucleus_limit,
+			BOOL production_mode)
 {
   Ordered = ordered;
   Check_instances = check_instances;
   Initial_nuclei = initial_nuclei;
   Ur_nucleus_limit = (ur_nucleus_limit == -1 ? INT_MAX : ur_nucleus_limit);
+  Production_mode = production_mode;
   Res_instance_prunes = 0;
+
 }  /* resolution_options */
 
 /*************
@@ -131,7 +137,7 @@ void hyper_sat_atom(BOOL flipped, Literals slit, Term atom, int pos_or_neg,
 				   UNIFY,
 				   sat_subst, nuc_subst,
 				   FALSE, &mate_pos);
-  while (fnd_atom) {
+  while (fnd_atom) {  /* loop through found nuclei atoms */
     /* it must be in a nucleus because of the index used above */
     Topform nuc = fnd_atom->container;
     Literals nuc_lit = atom_to_literal(fnd_atom);
@@ -152,20 +158,25 @@ void hyper_sat_atom(BOOL flipped, Literals slit, Term atom, int pos_or_neg,
 	p->flipped = flipped;
       }
       else {
-	p->clashable = positive ? !nlit->sign : nlit->sign;
+	if (!Production_mode)
+	  p->clashable = positive ? !nlit->sign : nlit->sign;
+	else
+	  p->clashable = (positive &&
+			  !nlit->sign &&
+			  !evaluable_predicate(SYMNUM(nlit->atom)));
 	if (p->clashable) {
 	  p->mate_index = positive ? idx->pos : idx->neg;
 	  p->sat_subst = get_context();
 	}
-      }  /* for each literal of nucleus */
-    }  /* if we have a nuc */
+      }
+    }  /* for each literal of nucleus */
     clash(first,
 	  positive ? pos_hyper_sat_test : neg_hyper_sat_test,
 	  HYPER_RES_JUST,
 	  proc_proc);
     zap_clash(first);
     fnd_atom = mindex_retrieve_next(mate_pos);
-  }  /* for each mate */
+  }  /* for each found nucleus atom */
   free_context(sat_subst);
   free_context(nuc_subst);
 }  /* hyper_sat_atom */
@@ -212,7 +223,12 @@ void hyper_nucleus(Topform c, int pos_or_neg, Lindex idx,
     p = append_clash(p);
     if (first == NULL)
       first = p;
-    p->clashable = positive ? !lit->sign : lit->sign;
+    if (!Production_mode)
+      p->clashable = positive ? !lit->sign : lit->sign;
+    else
+      p->clashable = (positive &&
+		      !lit->sign &&
+		      !evaluable_predicate(SYMNUM(lit->atom)));
     p->nuc_lit = lit;
     p->nuc_subst = nuc_subst;
     if (p->clashable) {
@@ -242,7 +258,9 @@ Hyperresolution.
 void hyper_resolution(Topform c, int pos_or_neg, Lindex idx,
 		      void (*proc_proc) (Topform))
 {
-  if (pos_or_neg == POS_RES ? positive_clause(c->literals) : negative_clause(c->literals))
+  if (pos_or_neg == POS_RES ?
+      positive_clause(c->literals) :
+      negative_clause(c->literals))
     hyper_satellite(c, pos_or_neg, idx, proc_proc);
   else
     hyper_nucleus(c, pos_or_neg, idx, proc_proc);
