@@ -336,3 +336,23 @@ char *double_to_str(double d,
   }
 }  /* double_to_str */
 
+/*************
+ *
+ *   string_of_repeated()
+ *
+ *************/
+
+/* DOCUMENTATION
+*/
+
+/* PUBLIC */
+BOOL string_of_repeated(char c, char *s)
+{
+  int i;
+  for (i = 0; i < strlen(s); i++)
+    if (s[i] != c)
+      return FALSE;
+  return TRUE;
+}  /* string_of_repeated */
+
+
