@@ -666,6 +666,12 @@ void simplify_literals2(Topform c)
       l->atom = NULL;
       null_literals = TRUE;
     }
+    else if ((!sign && true_term(a)) ||
+	     (sign && false_term(a))) {
+      zap_term(l->atom);
+      l->atom = NULL;
+      null_literals = TRUE;
+    }
     else if ((sign && eq_term(a) && term_ident(ARG(a,0), ARG(a,1))) ||
 	     (sign && true_term(a)) ||
 	     (!sign && false_term(a)))
