@@ -1362,7 +1362,7 @@ distinguish variables from constants.  This is it.
 BOOL variable_name(char *s)
 {
   if (variable_style() == PROLOG_STYLE)
-    return ((*s >= 'A' && *s <= 'Z') || *s == '_');
+    return (*s >= 'A' && *s <= 'Z');
   else if (variable_style() == INTEGER_STYLE)
     return (*s >= '0' && *s <= '9');
   else
@@ -1441,7 +1441,7 @@ Ilist variable_symbols(Ilist syms)
 
 /* DOCUMENTATION
 Given a Plist of symbols (symnums), remove the ones that
-are correspond to variables.
+correspond to variables.
 */
 
 /* PUBLIC */
