@@ -38,6 +38,58 @@ void assign_order_method(Order_method method)
   Ordering_method = method;
 }  /* assign_order_method */
 
+/*************
+ *
+ *   term_compare_basic(t1, t2)
+ *
+ *************/
+
+/* DOCUMENTATION
+This routine compares two terms.
+variable < nonvariable; within type, the order is by VARNUM
+and lexigocgaphic by ASCII ordering.  The range of return values is
+{SAME_AS, GREATER_THAN, LESS_THAN}.
+*/
+
+/* PUBLIC */
+Ordertype term_compare_basic(Term t1, Term t2)
+{
+  Ordertype  rc;
+
+  if (!VARIABLE(t1) && !VARIABLE(t2)) {
+    char *s1 = sn_to_str(SYMNUM(t1));
+    char *s2 = sn_to_str(SYMNUM(t2));
+    int a1 = ARITY(t1);
+    int a2 = ARITY(t2);
+    if (str_ident(s1, s2)) {
+      /* allow for different arities with same symbol */
+      int i;
+      for (rc = SAME_AS, i = 0; rc == SAME_AS && i < a1 && i < a2; i++)
+	rc = term_compare_basic(ARG(t1,i), ARG(t2,i));
+      if (rc == SAME_AS)
+	rc = (a1 < a2 ? LESS_THAN : (a1 > a2 ? GREATER_THAN : SAME_AS));
+    }
+    else {
+      int r = strcmp(s1, s2);
+      rc = (r < 0 ? LESS_THAN : (r > 0 ? GREATER_THAN : SAME_AS));
+    }
+  }
+
+  else if (VARIABLE(t1) && VARIABLE(t2)) {
+    if (VARNUM(t1) == VARNUM(t2))
+      rc = SAME_AS;
+    else
+      rc = (VARNUM(t1) > VARNUM(t2) ? GREATER_THAN : LESS_THAN);
+  }
+
+  else if (VARIABLE(t1))
+    rc = LESS_THAN;
+  else
+    rc = GREATER_THAN;
+
+  return rc;
+}  /* term_compare_basic */
+
 /*************
  *
  *    int term_compare_ncv(t1, t2)
@@ -144,7 +196,7 @@ Ordertype term_compare_vcp(Term t1, Term t2)
 This routine compares two terms.
 variable < nonvariable; within type, the order is by VARNUM
 and lexigocgaphic by symbol precedence.  The range of return values is<BR>
-{SAME_AS, GREATER_THAN, LESS_THAN, NOT_COMPARABLE}.
+{SAME_AS, GREATER_THAN, LESS_THAN}.
 */
 
 /* PUBLIC */
@@ -187,7 +239,7 @@ Ordertype term_compare_vr(Term t1, Term t2)
 This routine compares two flatterms.
 variable < nonvariable; within type, the order is by VARNUM
 and lexigocgaphic by symbol precedence.  The range of return values is<BR>
-{SAME_AS, GREATER_THAN, LESS_THAN, NOT_COMPARABLE}.
+{SAME_AS, GREATER_THAN, LESS_THAN}.
 */
 
 /* PUBLIC */
@@ -335,7 +387,7 @@ BOOL lrpo(Term s, Term t, BOOL lex_order_vars)
       return ok;
     }
 
-    else {  /* LESS_THEN or NOT_COMPARABLE */
+    else {  /* LESS_THAN or NOT_COMPARABLE */
       /* return (there is an arg of s s.t. arg >= t) */
       int i;
       BOOL ok;
@@ -497,7 +549,7 @@ BOOL term_greater(Term alpha, Term beta, BOOL lex_order_vars)
 
 /* DOCUMENTATION
 Compare two terms with the current term ordering (LPR, RPO, KBO)
-Return GREATER_THAN, LESS_THAN, or NOT_COMPARABLE.
+Return GREATER_THAN, LESS_THAN, SAME_AS, or NOT_COMPARABLE.
 */
 
 /* PUBLIC */
@@ -507,6 +559,8 @@ Ordertype term_order(Term alpha, Term beta)
     return GREATER_THAN;
   else if (term_greater(beta, alpha, FALSE))
     return LESS_THAN;
+  else if (term_ident(beta, alpha))
+    return SAME_AS;
   else
     return NOT_COMPARABLE;
 }  /* term_order */
