@@ -369,7 +369,6 @@ void flag_handler(FILE *fout, Term t, BOOL echo, int unknown_action)
       if (is_term(t,"set",1)) {
 	printf("\n    %% Declaring Mace4 arithmetic parse types.\n");
 	declare_parse_type("+",   490, INFIX_RIGHT);
-	declare_parse_type("--",  480, INFIX);
 	declare_parse_type("*",   470, INFIX_RIGHT);
 	declare_parse_type("/",   460, INFIX);
 	declare_parse_type("mod", 460, INFIX);
@@ -543,10 +542,7 @@ void input_symbols(int type, BOOL aux, Ilist *fsyms, Ilist *rsyms)
   Readlist p;
   for (p = Input_lists; p; p = p->next) {
     if (p->type == type && p->auxiliary == aux) {
-      I2list r = relation_symbols_in_formulas(*(p->p));
-      I2list f = function_symbols_in_formulas(*(p->p));
-      rsyms_multiset = multiset_union(rsyms_multiset, r);
-      fsyms_multiset = multiset_union(fsyms_multiset, f);
+      gather_symbols_in_formulas(*(p->p), &rsyms_multiset, &fsyms_multiset);
     }
   }
   *rsyms = multiset_to_set(rsyms_multiset);
@@ -554,6 +550,18 @@ void input_symbols(int type, BOOL aux, Ilist *fsyms, Ilist *rsyms)
   *fsyms = remove_variable_symbols(*fsyms);
   zap_i2list(fsyms_multiset);
   zap_i2list(rsyms_multiset);
+
+  if (FALSE) {
+    Ilist p;
+    printf("RSYMS: ");
+    for (p = *rsyms; p; p = p->next)
+      printf(" %s", sn_to_str(p->i));
+    printf("\n");
+    printf("FSYMS: ");
+    for (p = *fsyms; p; p = p->next)
+      printf(" %s", sn_to_str(p->i));
+    printf("\n");
+  }
 }  /* input_symbols */
 
 /*************
@@ -924,6 +932,7 @@ void check_formula_attributes(Formula f)
 
 /* DOCUMENTATION
 Input is Plist of Topforms containing formulas.
+Result is a Plist of Topforms containing clauses.
 */
 
 /* PUBLIC */
@@ -968,6 +977,48 @@ Plist process_input_formulas(Plist formulas, BOOL echo)
   return new;
 }  /* process_input_formulas */
 
+/*************
+ *
+ *   process_demod_formulas()
+ *
+ *************/
+
+/* DOCUMENTATION
+Input is Plist of Topforms containing formulas.
+Result is a Plist of Topforms containing clauses.
+*/
+
+/* PUBLIC */
+Plist process_demod_formulas(Plist formulas, BOOL echo)
+{
+  Plist new = NULL;  /* collect Topforms (clauses) to be returned */
+  Plist p;
+
+  for (p = formulas; p; p = p->next) {
+    Topform tf = p->v;
+    if (clausal_formula(tf->formula)) {
+      /* just make it into a clause data structure and use the same Topform */
+      tf->literals = formula_to_literals(tf->formula);
+      upward_clause_links(tf);
+      zap_formula(tf->formula);
+      tf->formula = NULL;
+      tf->is_formula = FALSE;
+      clause_set_variables(tf, MAX_VARS);
+      new = plist_prepend(new, tf);
+    }
+    else if (tf->formula->type == IMP_FORM ||
+	     tf->formula->type == IMPBY_FORM ||
+	     tf->formula->type == IFF_FORM) {
+       new = plist_prepend(new, tf);
+    }
+    else
+      fatal_error("process_demod_formulas: bad demodulator");
+  }
+  zap_plist(formulas);  /* shallow */
+  new = reverse_plist(new);
+  return new;
+}  /* process_demod_formulas */
+
 /*************
  *
  *   process_goal_formulas()
