@@ -642,97 +642,41 @@ void inherit_attributes(Topform par1, Context s1,
 
 /*************
  *
- *   function_symbols_in_topform()
+ *   gather_symbols_in_topform()
  *
  *************/
 
 /* DOCUMENTATION
-Collect the multiset of function symbols in a clause.
 */
 
 /* PUBLIC */
-I2list function_symbols_in_topform(Topform c, I2list g)
+void gather_symbols_in_topform(Topform c, I2list *rsyms, I2list *fsyms)
 {
   if (c->is_formula)
-    return function_symbols_in_formula(c->formula, g);
-  else {
-    Literals lit;
-    for (lit = c->literals; lit; lit = lit->next) {
-      int i;
-      for (i = 0; i < ARITY(lit->atom); i++) {
-	g = symbols_in_term(ARG(lit->atom,i), g);
-      }
-    }
-    return g;
-  }
-}  /* function_symbols_in_topform */
-
-/*************
- *
- *   relation_symbols_in_topform()
- *
- *************/
-
-/* DOCUMENTATION
-Collect the multiset of relation symbols in a clause.
-*/
-
-/* PUBLIC */
-I2list relation_symbols_in_topform(Topform c, I2list g)
-{
-  if (c->is_formula)
-    return relation_symbols_in_formula(c->formula, g);
+    gather_symbols_in_formula(c->formula, rsyms, fsyms);
   else {
     Literals lit;
     for (lit = c->literals; lit; lit = lit->next)
-      g = multiset_add(g, SYMNUM(lit->atom));
-    return g;
+      gather_symbols_in_formula_term(lit->atom, rsyms, fsyms);
   }
-}  /* relation_symbols_in_topform */
+}  /* gather_symbols_in_topform */
 
 /*************
  *
- *   function_symbols_in_topforms()
+ *   gather_symbols_in_topforms()
  *
  *************/
 
 /* DOCUMENTATION
-Collect the multiset of function symbols (including constants) in
-clauses in a Plist.
-An I2list of SYMNUMs is returned.
 */
 
 /* PUBLIC */
-I2list function_symbols_in_topforms(Plist lst)
+void gather_symbols_in_topforms(Plist lst, I2list *rsyms, I2list *fsyms)
 {
-  I2list syms = NULL;
   Plist p;
   for (p = lst; p; p = p->next)
-    syms = function_symbols_in_topform(p->v, syms);
-  return syms;
-}  /* function_symbols_in_topforms */
-
-/*************
- *
- *   relation_symbols_in_topforms()
- *
- *************/
-
-/* DOCUMENTATION
-Collect the multiset of relation symbols (including
-propositional constants) in clauses in a Plist.
-An I2list of SYMNUMs is returned.
-*/
-
-/* PUBLIC */
-I2list relation_symbols_in_topforms(Plist lst)
-{
-  I2list syms = NULL;
-  Plist p;
-  for (p = lst; p; p = p->next)
-    syms = relation_symbols_in_topform(p->v, syms);
-  return syms;
-}  /* relation_symbols_in_topforms */
+    gather_symbols_in_topform(p->v, rsyms, fsyms);
+}  /* gather_symbols_in_topforms */
 
 /*************
  *
@@ -746,10 +690,14 @@ I2list relation_symbols_in_topforms(Plist lst)
 /* PUBLIC */
 Ilist fsym_set_in_topforms(Plist lst)
 {
-  I2list a = function_symbols_in_topforms(lst);
-  Ilist b = multiset_to_set(a);
-  zap_i2list(a);
-  return b;
+  Ilist p;
+  I2list rsyms = NULL;
+  I2list fsyms = NULL;
+  gather_symbols_in_topforms(lst, &rsyms, &fsyms);
+  p = multiset_to_set(fsyms);
+  zap_i2list(rsyms);
+  zap_i2list(fsyms);
+  return p;
 }  /* fsym_set_in_topforms */
 
 /*************
@@ -764,10 +712,14 @@ Ilist fsym_set_in_topforms(Plist lst)
 /* PUBLIC */
 Ilist rsym_set_in_topforms(Plist lst)
 {
-  I2list a = relation_symbols_in_topforms(lst);
-  Ilist b = multiset_to_set(a);
-  zap_i2list(a);
-  return b;
+  Ilist p;
+  I2list rsyms = NULL;
+  I2list fsyms = NULL;
+  gather_symbols_in_topforms(lst, &rsyms, &fsyms);
+  p = multiset_to_set(rsyms);
+  zap_i2list(rsyms);
+  zap_i2list(fsyms);
+  return p;
 }  /* rsym_set_in_topforms */
 
 /*************
