@@ -625,6 +625,8 @@ Ilist syms_in_form(Term t, BOOL clausal)
       Ilist b = syms_in_form(ARG(t,1), TRUE);
       return ilist_union(a,b);
     }
+    else if (is_term(t, "$true", 0) || is_term(t, "$false", 0))
+      return NULL;
     else
       return fsym_set_in_term(t);
   }
@@ -652,6 +654,8 @@ Ilist syms_in_form(Term t, BOOL clausal)
       Ilist b = syms_in_form(ARG(t,1), FALSE);
       return ilist_union(a,b);
     }
+    else if (is_term(t, "$true", 0) || is_term(t, "$false", 0))
+      return NULL;
     else
       return fsym_set_in_term(t);
   }
@@ -666,10 +670,10 @@ Ilist syms_in_form(Term t, BOOL clausal)
 static
 BOOL good_tptp_sym(char *s)
 {
-  /* [a-z][a-zA-Z0-9_]* */
   if (strlen(s) == 0)
     return FALSE;
   else {
+    /* [a-z][a-zA-Z0-9_]* */
     if (!(s[0] >= 'a' && s[0] <= 'z'))
       return FALSE;
     else {
