@@ -31,7 +31,9 @@
 
 /* Public function prototypes from tptp_trans.c */
 
-void declare_tptp_parse_types(void);
+void declare_tptp_input_types(void);
+
+void declare_tptp_output_types(void);
 
 Formula tptp_input_to_ladr_formula(Term t);
 
@@ -39,7 +41,11 @@ Plist ladr_list_to_tptp_list(Plist in, char *name, char *type);
 
 Ilist syms_in_form(Term t, BOOL clausal);
 
-I2list map_for_bad_tptp_syms(Ilist syms);
+I2list map_for_bad_tptp_syms(Ilist syms, BOOL quote_bad_syms);
+
+I2list map_for_bad_ladr_syms(Ilist syms, BOOL quote_bad_syms);
+
+Term replace_bad_syms_term(Term t, I2list map);
 
 Term replace_bad_tptp_syms_form(Term t, BOOL clausal, I2list map);
 
