@@ -19,6 +19,7 @@
 #include "weight.h"
 #include "weight2.h"
 #include "parse.h"
+#include "complex.h"
 
 /* Private definitions and types */
 
@@ -33,6 +34,7 @@ static double Variable_weight;
 static double Nest_penalty;
 static double Depth_penalty;
 static double Var_penalty;
+static double Complexity;
 static BOOL Not_rules;  /* any rules for not_sym()? */
 static BOOL Or_rules;   /* any rules for or_sym()? */
 
@@ -129,7 +131,8 @@ void init_weight(Plist rules,
 		 double prop_atom_weight,
 		 double nest_penalty,
 		 double depth_penalty,
-		 double var_penalty)
+		 double var_penalty,
+		 double complexity)
 {
   Plist p;
 
@@ -142,6 +145,7 @@ void init_weight(Plist rules,
   Nest_penalty = nest_penalty;
   Depth_penalty = depth_penalty;
   Var_penalty = var_penalty;
+  Complexity = complexity;
 
   /* Cache symbol numbers. */
 
@@ -391,6 +395,9 @@ double clause_weight(Literals lits)
 
   if (Var_penalty != 0)
     wt += Var_penalty * number_of_variables(lits);
+ 
+  if (Complexity != 0)
+    wt += Complexity * (1 - clause_complexity(lits, 4, 0));
 
   return wt;
 
