@@ -40,7 +40,8 @@ void init_weight(Plist rules,
 		 double prop_atom_weight,
 		 double nest_penalty,
 		 double depth_penalty,
-		 double var_penalty);
+		 double var_penalty,
+		 double complexity);
 
 double weight(Term t, Context subst);
 
