@@ -36,6 +36,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#define IMAX(a,b) ((a) > (b) ? (a) : (b))
 #else
 #include "weight2.h"
 #include "parse.h"
@@ -193,7 +194,7 @@ int main(int argc, char **argv)
 
     /* printf("\nchecking %s\n", s); */
 
-    printf("%.5f\n", complexity_1(s));
+    printf("%.5f\n", 1 - complexity_1(s));
 
   }
 }
