@@ -31,6 +31,6 @@
 
 /* Public function prototypes from weight2.c */
 
-int call_weight(char *program, Term t);
+double call_weight(char *func, Term t);
 
 #endif  /* conditional compilation of whole file */
