@@ -21,6 +21,7 @@
 
 extern int Negation_flag;  /* for dealing with mclause */
 extern Term *Domain;
+extern int Domain_size;
 
 /* Private definitions and types */
 
@@ -32,6 +33,7 @@ static int Mod_sn;
 static int Min_sn;
 static int Max_sn;
 static int Abs_sn;
+static int Domain_size_sn;
 static int Lt_sn;
 static int Le_sn;
 static int Gt_sn;
@@ -66,6 +68,7 @@ void init_arithmetic(void)
   Arith_op_sn[Min_sn = str_to_sn("min", 2)] = TRUE;
   Arith_op_sn[Max_sn = str_to_sn("max", 2)] = TRUE;
   Arith_op_sn[Abs_sn = str_to_sn("abs", 1)] = TRUE;
+  Arith_op_sn[Domain_size_sn = str_to_sn("domain_size", 0)] = TRUE;
 
   Arith_rel_sn[Le_sn = str_to_sn("<=", 2)] = TRUE;
   Arith_rel_sn[Lt_sn = str_to_sn("<", 2)] = TRUE;
@@ -289,6 +292,8 @@ int arith_evaluate(Term t, BOOL *evaluated)
       return -arith_evaluate(ARG(t,0), evaluated);
     else if (sn == Abs_sn)
       return abs(arith_evaluate(ARG(t,0), evaluated));
+    else if (sn == Domain_size_sn)
+      return Domain_size;
     else if (sn == Min_sn) {
       int a0 = arith_evaluate(ARG(t,0), evaluated);
       int a1 = arith_evaluate(ARG(t,1), evaluated);
