@@ -334,7 +334,15 @@ Term simp_term(Term t)
 static
 Term simp_tv(Term t)
 {
-  if (OR_TERM(t)) {
+  if (true_term(t)) {
+    zap_mterm(t);
+    return Domain[1];
+  }
+  else if (false_term(t)) {
+    zap_mterm(t);
+    return Domain[0];
+  }
+  else if (OR_TERM(t)) {
     t = merge(t);
     if (!OR_TERM(t))
       return simp_tv(t);
