@@ -127,7 +127,7 @@ Plist read_mace4_input(int argc, char **argv, BOOL allow_unknown_things,
 
   // Accept hints, but they will not be used.
 
-  accept_list("hints", FORMULAS, FALSE, &hints);
+  accept_list("hints", FORMULAS, TRUE, &hints);
 
   // Accept goals; these are negated individually (each must be falsified)
 
@@ -139,7 +139,7 @@ Plist read_mace4_input(int argc, char **argv, BOOL allow_unknown_things,
 
   // Accept any other clauses and formulas.  Each must be true.
 
-  accept_list("",    FORMULAS, TRUE, &wild_formulas);
+  accept_list("",    FORMULAS, FALSE, &wild_formulas);
 
   // Accept any terms.  These will not be used.
 
