@@ -235,7 +235,7 @@ void propagate_negative(int type, int id, Term alpha, Term beta, int pos,
 
 /* from ordercells.c */
 
-void order_cells(BOOL skolems_last, BOOL verbose);
+void order_cells(BOOL verbose);
 
 /* from commandline.c */
 
