@@ -226,13 +226,14 @@ void update_selectors(Topform c, BOOL insert)
   }
   if (!matched) {
     static BOOL Already_warned = FALSE;
-    printf("\nWARNING: the following clause does not match "
-	   "any given_selection rules.\n");
-    f_clause(c);
 
     if (!Already_warned) {
       fprintf(stderr, "\n\nWARNING: one or more kept clauses do not match "
 	     "any given_selection rules (see output).\n\n");
+      printf("\nWARNING: the following clause does not match "
+	     "any given_selection rules.\n"
+	     "This message will not be repeated.\n");
+      f_clause(c);
       Already_warned = TRUE;
     }
   }
