@@ -240,7 +240,7 @@ int NewAuto(Prover_input input, Plist assumptions)
 
             // return current to active pool
             assumptions_active
-               = plist_prepend(assumptions_active, assumption_current);
+               = plist_append(assumptions_active, assumption_current);
 
             list_size = plist_count(assumptions_in_proof);
             printf("\n%d candidate assumptions to eliminate:\n", list_size);
