@@ -338,7 +338,7 @@ Prover_input std_prover_init_and_input(int argc, char **argv,
 
     pi->sos    = process_input_formulas(pi->sos, echo);
     pi->usable = process_input_formulas(pi->usable, echo);
-    pi->demods = process_input_formulas(pi->demods, echo);
+    pi->demods = process_demod_formulas(pi->demods, echo);
     pi->hints  = process_input_formulas(pi->hints, echo);
     denials    = process_goal_formulas(pi->goals, echo);
 
