@@ -80,6 +80,7 @@ struct prover_options {
     back_demod_hints,
     collect_hint_labels,
     dont_flip_input,
+    eval_rewrite,
 
     echo_input,              // output
     bell,
@@ -114,6 +115,7 @@ struct prover_options {
     auto_process,
     auto2,                 // enhanced auto mode
     raw,
+    production,
 
     lex_order_vars,       // others
     ignore_option_dependencies;
@@ -145,6 +147,7 @@ struct prover_options {
     random_part,
     random_seed,
     eval_limit,
+    eval_var_limit,
 
     max_weight,            // processing generated clauses
     max_depth,
@@ -165,6 +168,7 @@ struct prover_options {
     depth_penalty,
     var_penalty,
     default_weight,
+    complexity,
 
     sos_limit,             // control size of SOS
     sos_keep_factor,
