@@ -188,7 +188,7 @@ Prover_options init_prover_options(void)
   p->max_given =        init_parm("max_given",            -1,     -1,INT_MAX);
   p->max_kept =         init_parm("max_kept",             -1,     -1,INT_MAX);
   p->max_proofs =       init_parm("max_proofs",            1,     -1,INT_MAX);
-  p->max_megs =         init_parm("max_megs",            200,     -1,INT_MAX);
+  p->max_megs =         init_parm("max_megs",            500,     -1,INT_MAX);
   p->max_seconds =      init_parm("max_seconds",          -1,     -1,INT_MAX);
   p->max_minutes =      init_parm("max_minutes",          -1,     -1,INT_MAX);
   p->max_hours =        init_parm("max_hours",          -1,     -1,INT_MAX);
@@ -1049,7 +1049,7 @@ void handle_proof_and_maybe_exit(Topform empty_clause)
 
     printf("%% Length of proof is %d.\n", proof_length(proof));
     printf("%% Level of proof is %d.\n", clause_level(empty_clause));
-    printf("%% Maximum clause weight is %d.\n", max_clause_weight(proof));
+    printf("%% Maximum clause weight is %.3f.\n", max_clause_weight(proof));
     printf("%% Given clauses %d.\n\n", Stats.given);
     for (p = proof; p; p = p->next)
       fwrite_clause(stdout, p->v, CL_FORM_STD);
@@ -2780,7 +2780,12 @@ Prover_results forking_search(Prover_input input)
     perror("");
     fatal_error("forking_search: fork failed");
   }
-  
+
+  {  /* kludge to get labels that might be introduced by child into symtab */
+    int i = str_to_sn("flip_matches_hint", 0);
+    i++;  /* prevents warning about unused variable */
+  }
+
   if (rc == 0) {
 
     /*********************************************************************/
