@@ -25,7 +25,6 @@ enum { FALSE_IN_ALL,
 };
 
 static Plist Compiled_interps = NULL;
-static int Max_domain_size = 0;
 static int Eval_limit = 0;
 static BOOL False_in_all;
 static Clock Eval_clock;
@@ -43,24 +42,30 @@ compile them, and store them locally.
 
 /* PUBLIC */
 void init_semantics(Plist interp_terms, Clock eval_clock,
-		    char *type, int eval_limit)
+		    char *type, int eval_limit, int eval_var_limit)
 {
   Plist p;
+  int max_domain_size = 0;
   
   for (p = interp_terms; p; p = p->next) {
     Interp a = compile_interp(p->v, FALSE);
-    Max_domain_size = IMAX(Max_domain_size, interp_size(a));
+    max_domain_size = IMAX(max_domain_size, interp_size(a));
     Compiled_interps = plist_prepend(Compiled_interps, a);
   }
   Compiled_interps = reverse_plist(Compiled_interps);
-  Eval_limit = eval_limit;
-  Eval_clock = eval_clock;
   if (str_ident(type, "false_in_all"))
     False_in_all = TRUE;
   else if (str_ident(type, "false_in_some"))
     False_in_all = FALSE;
   else
     fatal_error("init_semantics, bad type");
+  if (eval_var_limit == -1)
+    Eval_limit = eval_limit;
+  else {
+    Eval_limit = int_power(max_domain_size, eval_var_limit);
+    printf("eval_limit reset to %d.\n", Eval_limit);
+  }
+  Eval_clock = eval_clock;
 }  /* init_semantics */
 
 /*************
