@@ -32,7 +32,7 @@
 /* Public function prototypes from semantics.c */
 
 void init_semantics(Plist interp_terms, Clock eval_clock,
-		    char *type, int eval_limit);
+		    char *type, int eval_limit, int eval_var_limit);
 
 void eval_in_interps(Topform c);
 
