@@ -106,8 +106,9 @@ int main(int argc, char **argv)
   /* Collect all of the function and predicate symbols. */
 
   {
-    I2list f = function_symbols_in_formulas(all);
-    I2list r = relation_symbols_in_formulas(all);
+    I2list f = NULL;
+    I2list r = NULL;
+    gather_symbols_in_formulas(all, &r, &f);
     Ilist rsyms = multiset_to_set(r);
     Ilist fsyms = multiset_to_set(f);
     zap_i2list(f);
