@@ -244,8 +244,9 @@ void symbol_order(Clist usable, Clist sos, Clist demods, BOOL echo)
   nonneg = nonneg_clauses(all);
   zap_plist(all);
 
-  fsyms_multiset = function_symbols_in_topforms(nonneg);
-  rsyms_multiset = relation_symbols_in_topforms(nonneg);
+  rsyms_multiset = NULL;
+  fsyms_multiset = NULL;
+  gather_symbols_in_topforms(nonneg, &rsyms_multiset, &fsyms_multiset);
 
   lex_order(fsyms, rsyms, fsyms_multiset, rsyms_multiset,
 	    lex_compare_arity_0213);
